# gus
Green Urban Scenarios - A digital twin representation, simulation of urban forests and their impact analysis.

## install GUS from Test-PyPi

```
import sys
!{sys.executable} -m pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple gus==0.1.7
```
